;***************************************************************************************************
;
;	PROJETO : TERMOMETRO ELETRNICO COM VISOR DE TEMPERATURA COM LCD
;
;   INICIO : 15/01/13 TERM.:16/01/13
;	AUTOR:  CLUDIO CARMONA LRIOS
;	PROCESSADOR:  PIC   16F676
;   PROJETO DIDTICO APENAS.		
;	OBJETIVO: MOSTRAR  A TEMPERATURA DE UM SENSOR LM35  EM LCD DE 16X2
;   APLICAO: MONITORAR TEMPERATURA AMBIENTE 
;   ESCALA: 0 C A 150 C (LIMITE DO LM35)

;   PINAGEM:
;   PINO 1  = VCC
;   PINO 4  = RESET
;   PINO 5  = E (LCD)
;   PINO 6  = RS (LCD)
;   PINO 7  = DB4 (LCD)
;   PINO 8  = DB5 (LCD)
;   PINO 9  = DB6 (LCD)
;   PINO 10 = DB7 (LCD)
;   PINO 12 = V REF (AJUSTE DE CALIBRAO = 2,048 VOLTS)
;   PINO 13 = SENSOR LM35
;   PINO 14 = GND
;___________________________________________________________________________________________________
;
	LIST P=16f676 , R=DEC
    INCLUDE "P16F676.INC" 		;ARQUIVO PADRAO	
  	ERRORLEVEL      -302   		;ELIMINA MENSAGEM DE ERRO
;PALAVRA DE CONFGURAO:
   __CONFIG		_CP_OFF & _PWRTE_ON & _WDT_OFF & _INTRC_OSC_NOCLKOUT & _BODEN & _MCLRE_ON
	    

;PAGINACAO DE MEMORIA;
#DEFINE		BANK0	BCF	STATUS,RP0 	;SETA BANK0 DE MEMORIA
#DEFINE		BANK1	BSF	STATUS,RP0	;SETA BANK1
;						VARIAVEIS DA RAM
		CBLOCK		0X20		;ENDERECO INICIAL DE MEMORIA
		    	CONT0			;CONTADOR AUXILIAR PARA RESULTADO PARTE BAIXA DA CONVERSO
				CONT1			;CONTADOR AUXILIAR PARA RESULTADO PARTE ALTA DA  CONVERSO
			   	CONT0A			;CONTADOR AUXILIAR PARA RESULTADO PARTE BAIXA DA CONVERSO
				CONT1A			;CONTADOR AUXILIAR PARA RESULTADO PARTE ALTA DA  CONVERSO
			    TEMP			;TEMPORRIO
                AUX             ;IDEM
                AUX1            ;IDEM
                LC              ;DELAY
                LC1             ;IDEM
                TR              ;BUFFER PARA ENVIO DO LCD
				C0              ;REGISTRADOR PARA CONVERSO
				C1              ;IDEM
                C2
				BR0				;RESULTADO DE CONVERSO
                BR1             ;IDEM
                BR2             ;IDEM
                R0              ;AUXILIAR USADO NA CONVERSO HEXA PARA ASCII
                R1              ;IDEM
                PAG				;AUX DE SALTO GOTO
                FLAGS           ;FLAGS
				ASOMAH          ;ACUMULA SOMA SUCESSIVA HIGH
			    ASOMAL          ;ACUMULA SOMA SUCESSIVA LOW
                LEITOLDH        ;LEITURA ANTERIOR H
				LEITOLDL        ;LEITURA ANTERIOR L
                NL              ;NMERO DE LEITURAS
                
        ENDC
  
;***********************************************************************************************
;						CONSTANTES

#DEFINE			LIGAC		ADCON0,1;DEFINE PALAVRA PARA LIGAR/DESLIGAR CONVERSO   
#DEFINE         LCD_DB7     PORTC,0  ;PINO 10
#DEFINE         LCD_DB6     PORTC,1  ;PINO 9
#DEFINE         LCD_DB5     PORTC,2  ;PINO 8
#DEFINE         LCD_DB4     PORTC,3  ;PINO 7
#DEFINE         LCD_RS      PORTC,4  ;PINO 6
#DEFINE         LCD_E       PORTC,5  ;PINO 5
#DEFINE         FLAG_ZESQ   FLAGS,0  ;FLAG INDICADOR DE ZEROS A ESQUERDA
#DEFINE         FLAG_NC     FLAGS,1  ;FLAG DE NOVA CONVERSO
#DEFINE         FLAG_NCA    FLAGS,2  ;FLAG DE REPETE NOVA CONVERSO
T_APRES         EQU         .20      ;TEMPO DE APRESENTAO DAS MENSAGENS
T_LEIT          EQU         .2       ;TEMPO DE APRESENTAO DA ULTIMA COMVERSO
VLINHA1         EQU  80H             ;ENDEREO DA LINHA 1
VLINHA2         EQU  0C0H			 ;ENDEREO DA LINHA 2
;=====================================================================================
;MACROS
LIMPA  MACRO		;LIMPA TELA DO LCD
    CALL   LcdClear
   	MOVLW 	.7     ;AJUSTAR 5 MSEG
    CALL   DELAY
    ENDM
LINHA1 MACRO        ;TROCA PARA LINHA 1 DO LCD
    CALL   LINE1
   	MOVLW 	.7     ;AJUSTAR 5 MSEG
    CALL   DELAY
    ENDM
LINHA2 MACRO        ;TROCA PARA LINHA 2 DO LCD
    CALL   LINE2
   	MOVLW 	.7     ;AJUSTAR 5 MSEG
    CALL   DELAY
    ENDM
   

;=========================================================================================
;							VETOR DE  RESET
		ORG 0X00	
 			GOTO INICIO
;=========================================================================================
;						VETOR DE INTERRUPCAO
		ORG	0X04
			RETFIE

;=========================================================================================
;PAGINA ZERO
;ROTINA PARA ENVIO DE FRASES PARA O  LCD				
ENV_LCD
	MOVWF  AUX
    MOVFW  PAG
    MOVWF  PCLATH
    MOVFW  AUX
RT1
    CALL PEGA_M
    ADDLW  .0
    BTFSC  STATUS,Z
    RETURN
    CALL    ED
    INCF   AUX,F
    MOVFW   AUX
    GOTO  RT1

PEGA_M
    MOVWF    PCL
FRASE1:
	dt " PIC_TERMOMETRO ",0
FRASE2:
	dt "LARIOS.TECNOL.WS",0
FRASE3:
	dt " TEMP = ",0
FRASE4:
	dt "TEMP.LIMITE ",0


;==================================================================================
; 			INICIO DO PROGRAMA  DO PROGRAMA PRINCIPAL
;==================================================================================		
;CONFIGURAES INICIAIS DOS REGISTRADORES E PORTAS
INICIO
			BANK1	       			;BANCO  1
;===================================================================================
;  COMENTE AS DUAS LINHAS ABAIXO SE VOCE PERDEU O BYTE DE CALIBRAO DO SEU PIC
			CALL		0X03FF		;BUSCA CALIBRAO DO OSCILADOR
			MOVWF		OSCCAL		;TRANSFERE PARA O REG.OSCILADOR
;====================================================================================
			MOVLW		.0
 			MOVWF		INTCON		;DESLIGA TODAS INTERRUPCOES
			MOVLW		b'00000011'	;DEFINE ENTRADAS (1) E SAIDAS (0) NA PIO
			MOVWF		TRISA		;
			CLRF		TRISC
			MOVLW		B'10000000'	;DESAHABILITA  PULL-UP DA PIO
			MOVWF		OPTION_REG	;IDEM
			MOVLW		B'00100000' ;SELEO  DE FREQUENCIA DE CONVERSO ( OSC/32)
			MOVWF		ADCON1		;
			CLRF		ANSEL       ;DEIXA SAIDAS TODAS PARA DIGITAL
			CLRF		VRCON       ;DESLIGA TENSO DE REFERENCIA
			BANK0
			MOVLW		.7          ;DESLIGA COMPARADORES ANALGICOS
			MOVWF		CMCON
			MOVLW		B'11000001';LIGA  CONVERSOR AN/DIG	(USA TENSO EM PORTA1 COMO REFERNCIA)	
			MOVWF		ADCON0		;ESCOLHE CANAL 0/REF AO VCC/MODO DE SAIDA PARA DIREITA
			CLRF		PORTA		;LIMPA PORTA E C
            CLRF        PORTC
			CLRF        FLAGS       ;IDEM FLAGS
            CLRF        LEITOLDH    ;LIMPA LEITURA ANTERIORES
            CLRF        LEITOLDL

		    CALL        LcdInit     ;INICIALIZA LCD


            CALL        FRASEINIT   ;ENVIA FRASE COM O NOME DO APARELHO
 			MOVLW       T_APRES      ;TEMPO DE APRESENTAO DA MENSAGEM
            CALL        DELAYW
;============================================================================================
;    LOOP   PRINCIPAL
;============================================================================================
MAIN		NOP
            BANK1
           	MOVLW		B'00000001'	;SELECIONA  RA0 COMO ANALOGICA (ADC)
			MOVWF		ANSEL
            BANK0
;============================================================================================
; SEGUE UMA SEQUENCIA DE 32 LEITURAS DA TEMPERATURA DO LM35
            BCF         FLAG_ZESQ   ;FLAG DE ZERO A ESQUERDA
			CALL        LER_TEMP    ;VALORES DA TEMPERATURA EM C1/C0
  ;=============================================================================
; APRESENTA A MDIA DE 32 LEITURAS      
			CALL		CONVDEC		;CONVERTE PARA DECIMAL OS RESULTADOS H E L
    		CALL        MOSTRA_TEMP ;MOSTRA RESULTADO NO LCD       
			MOVLW       T_LEIT     ;DELAY DE APRESENTAO DO RESULTADO
            CALL        DELAYW
            GOTO        MAIN        ;VOLTA AO LOOP PRINCIPAL PARA REPETIR LEITURAS







;======================================================================================================
;                  SUB-ROTINAS
;======================================================================================================

;ROTINA DE LEITURA DA TEMPERATURA DO LM35
LER_TEMP
			MOVLW       .32         ;NMERO DE 32 LEITURAS DO LM35
            MOVWF       NL
            CLRF        ASOMAH      ;LIMPA REGISTRADORES DE SOMA TOTAL
            CLRF        ASOMAL
NOVA_LEITURA
         	BSF			LIGAC		;INICIA CONVERSO
    		BTFSC		LIGAC		;TESTA SE CHEGOU AO FIM DA CONVERSO
			GOTO		$-1			;SE NO  LOOP AT TERMINO DA CONVERSO
			MOVFW		ADRESH	
			MOVWF		C1			;CARREGA CONTADOR AUXILIAR COM  RESULTADO ALTO
        	BANK1
			MOVFW		ADRESL  	;OBTEM A PARTE BAIXA DA CONVERSO
            CLRF        ANSEL
			BANK0
			MOVWF		C0			;CARREGA CONTADOR AUXILIAR 1 COM RESULTADO BAIXO
            CALL        SOMAR
            DECFSZ      NL,F
            GOTO        NOVA_LEITURA
            MOVLW       .4
            MOVWF       NL
;DIVIDE POR 8 (P/ OBTER PLENA ESCALA DE 0 - 150 )
NOVO_DESLOC 
            BCF         STATUS,C
            RRF         ASOMAH,F
      		RRF         ASOMAL,F
            DECFSZ      NL,F
            GOTO        NOVO_DESLOC
            MOVFW       ASOMAH
            MOVWF       C1
            MOVFW       ASOMAL
            MOVWF       C0


;=======================================================================
;  TESTA SE REGISTRADOR DE LEITURA ANTERIOR ESTA VAZIO APS RESET
			MOVF        LEITOLDH,F
            BTFSS       STATUS,Z
            GOTO        GRADIC
			MOVF        LEITOLDL,F
            BTFSS       STATUS,Z
            GOTO        GRADIC
            MOVFW       C1              ;PRIMEIRO VALOR EM LEITURA ANTIGA
            MOVWF       LEITOLDH
            MOVFW       C0
            MOVWF       LEITOLDL

;=======================================================================
            RETURN   
 
;
; MELHORA A INSTABILIDADE NO ULTIMO DIGITO
;   FRMULA NO USUAL  P/ MDIA COM A LEITURA ANTERIOR:

;           LEITURA ATUAL X (N-1) + LEITURA ANTERIOR
;           ____________________________________
;                        N
GRADIC 
	        MOVLW       .3
		;	MOVLW       .15
            MOVWF       NL
            MOVFW       C1
            MOVWF       C2   ;SALVA C1
            CLRF        ASOMAH      ;LIMPA REGISTRADORES DE SOMA TOTAL
            CLRF        ASOMAL
NOVA_SOMA_INC
            MOVFW       C2
            MOVWF       C1
            CALL        SOMAR
            DECFSZ      NL,F
            GOTO        NOVA_SOMA_INC
            MOVFW       LEITOLDH
            MOVWF       C1   ;RECUPERA LEITURA ANTERIOR        
            MOVFW       LEITOLDL
            MOVWF       C0   ;RECUPERA LEITURA ANTERIOR 
            CALL        SOMAR  
			MOVLW       .2   ;DIVIDE POR 4 VIA DESLOCAMENTO A DIREITA
          ;  MOVLW       .4  ;DIVIDE POR 16 VIA DESLOCAMENTO A DIREITA
            MOVWF       NL
NOVO_DESLOC1 
            BCF         STATUS,C
            RRF         ASOMAH,F
      		RRF         ASOMAL,F
            DECFSZ      NL,F
            GOTO        NOVO_DESLOC1
            MOVFW       ASOMAH
            MOVWF       C1
			MOVWF       LEITOLDH   ;SALVA COMO LEITURA ANTERIOR
            MOVFW       ASOMAL
            MOVWF       C0
	        MOVWF       LEITOLDL  ;SALVA COMO LEITURA ANTERIOR
            RETURN  

;ROTINA DE SOMA 16 BITS
SOMAR       ;C1/C2 + ASOMAH;/ASOMAL => ASOMAH/ASOMAL
 			MOVFW       C0
            ADDWF       ASOMAL,F
            MOVLW       .1
            BTFSS       STATUS,C
            MOVLW       .0
            ADDWF       C1,F
            MOVLW       .1
            BTFSS       STATUS,C
            MOVLW       .0
            MOVFW       C1
            ADDWF       ASOMAH,F;COMO NO SE ATINGIR MXIMO DE 0XFFFF, C/ 32 SOMAS PARAMOS AQUI.
			RETURN

; ROTINA DE APRESENTAO NO LCD
MOSTRA_TEMP 
    
    LINHA2
    CLRF   PAG
    MOVLW  FRASE3
    CALL   ENV_LCD
    MOVLW  0XC8     				;POSIO NA LINHA ONDE SER ESCRITO O VALOR DA TEMPERATURA
    CALL   EC
    MOVFW  BR1      
    CALL  conv_asc2                 ;CONVERTE PARA ASCII
    MOVWF   AUX
    XORLW   0X30                    ;TESTA SE  ZERO A ESQUERDA
    BTFSS   STATUS,Z
    GOTO    SEGUI2
    BSF     FLAG_ZESQ
    MOVLW   ' '                     ;APAGA ZERO A ESQUERDA
    GOTO    SEGUI4
SEGUI2
    MOVFW   AUX
SEGUI4
	CALL ED         				;ULTIMO ZERO
    MOVFW   R1
    BTFSS   FLAG_ZESQ
    GOTO    SEGUI3
    XORLW   0X30                    ;VERIFICA SE  ZERO
    MOVLW   ' '      				;SE ZERO ENVIA ESPAO
    BTFSS   STATUS,Z
    MOVFW   R1
SEGUI3
	CALL ED                         ;ENVIA CENTENA
      
	MOVFW  BR0
    CALL  conv_asc2                 ;ENVIA DEZENA
	CALL ED

    MOVLW   '.'						;ENVIA PONTO
    CALL ED
   	MOVFW  R1						;ENVIA UNIDADE
    CALL ED
    MOVLW  ' '
    CALL   ED						;ENVIA 'C' (CENTIGRADOS)
    MOVLW  'C'
    CALL   ED
    MOVLW  ' '                      ;ENVIA ESPAO 
    CALL   ED
  
    RETURN

CONVDEC
;**************************************************************************
;		ROTINA PARA CONVERSO  DE 16 BITS PARA  5 BCD (3BYTES)
;
;
;	EX: C0=FF
;		C1=FF		
;	 SER  APS CONVERSO :
;		BR2=06 , BR1=55  ,BR0=35  (OBS.  VALOR MXIMO 65535)
;***************************************************************************

;   RESERVAR ESTES REGISTRADORES NA   MEMRIA ( SRAM)
;	LC   data 20H	;LOOPCOUNTER
;	BR0 data 21H	;RESULTADOS DA CONVERSO
;	BR1 data 22H
;	BR2 data 23H
;	C1   data 24H	;VALOR DE ENTRADA ALTO
;	C0   data 25H	;BAIXO
HEX_DEC:	
    MOVLW .16
	MOVWF  LC     ;CARREGA 16
	CLRF  BR0 	;ZERA RESULTADOS
	CLRF  BR1 
	CLRF  BR2 

VOLTA:	
    BCF  STATUS,C
	RLF  C0,F    ;DESLOCA PARA ESQUERDA C0,C1,BR0,1,2
	RLF  C1,F 
	RLF  BR0,F  
	RLF  BR1,F 
	RLF  BR2,F
	DECFSZ LC,F  ;VERIFICA SE CHEGOU AO FIM DA CONVERSO
    GOTO SEG9
	RETURN			;FI DA CONVERSO
SEG9:
	MOVLW .3 
	ADDWF BR2,W	;SOMA  3 EM RES2
	ANDLW .8 	; 2ELEV 3=8
    XORLW .8
    BTFSS  STATUS,Z
    GOTO  NSOMA3		;=0 ,ENTO NO SOMA 3 (SE ZERO RETORNA VALOR ORIGINAL)
	MOVLW .3
    ADDWF BR2,F 		; =1 ENTAO SOMA 3

NSOMA3:
	MOVLW 0X30
	ADDWF BR2,W
	ANDLW  0X80 
    XORLW  0X80
    BTFSS  STATUS,Z
    GOTO   NSOMA3A		;=0 ,ENTO NO SOMA 30h
	MOVLW 0X30 	; =1 ENTAO SOMA 30h
	ADDWF  BR2,F

NSOMA3A:
	MOVLW .3 
	ADDWF BR1,W	;SOMA  3 EM RES2
	ANDLW .8 	; 2ELEV 3=8
    XORLW .8
    BTFSS  STATUS,Z
    GOTO  NSOMA3B		;=0 ,ENTO NO SOMA 3 (SE ZERO RETORNA VALOR ORIGINAL)
	MOVLW .3
    ADDWF BR1,F 		; =1 ENTAO SOMA 3
NSOMA3B:
	MOVLW 0X30
	ADDWF BR1,W
	ANDLW  0X80 
    XORLW  0X80
    BTFSS  STATUS,Z
    GOTO   NSOMA3C		;=0 ,ENTO NO SOMA 30h
	MOVLW 0X30 	; =1 ENTAO SOMA 30h
	ADDWF  BR1,F
NSOMA3C:
	MOVLW .3 
	ADDWF BR0,W	;SOMA  3 EM RES2
	ANDLW .8 	; 2ELEV 3=8
    XORLW .8
    BTFSS  STATUS,Z
    GOTO  NSOMA3D		;=0 ,ENTO NO SOMA 3 (SE ZERO RETORNA VALOR ORIGINAL)
	MOVLW .3
    ADDWF BR0,F 		; =1 ENTAO SOMA 3
NSOMA3D:
	MOVLW 0X30
	ADDWF BR0,W
	ANDLW  0X80 
    XORLW  0X80
    BTFSS  STATUS,Z
    GOTO   NSOMA3E		;=0 ,ENTO NO SOMA 30h
	MOVLW 0X30 	; =1 ENTAO SOMA 30h
	ADDWF  BR0,F
NSOMA3E:
	GOTO VOLTA
;================================================================================
CONV_ASC2:
conv_asc2:  ; converte 2 nibles hex em 2 nibles asc2 lsb=r1 msb=a  

	MOVWF R0 
	ANDLW 0X0F
	ADDLW  0XF6 
	BTFSC  STATUS,C 
	GOTO LETRAS
	ADDLW  0X3A 
	GOTO SAIQ

LETRAS:
	ADDLW	0X41 

SAIQ:
	MOVWF R1 
	SWAPF R0,F
    MOVFW R0
    ANDLW  0X0F 
    ADDLW  0XF6 
    BTFSC  STATUS,C  
    GOTO   LETRAS1
    ADDLW  0X3A 
    GOTO  SAIQ1

LETRAS1:
   ADDLW	0X41 
SAIQ1:
   RETURN
;================================================================================

;ROTINAS DE DELAY     


DELAY2
				MOVLW .20
DELAYW
DELAYM
				MOVWF TEMP
VJ1				call  LcdDelay1
	    		DECFSZ TEMP,F
				GOTO  VJ1
DELAY1
LcdDelay1		MOVLW   .255     ;DELAY PARA VISUALIZAAO

DELAY
LcdDelay
				goto $+1
				movwf   LC+1	;duas variveis em uma
LcdDelayLoop					
                decfsz  LC+0,F		;dec. o prim. cont.
                goto    LcdDelayLoop
                decfsz  LC+1,F		;dec. o seg. cont.
                goto    LcdDelayLoop
                return

DEBOUNCE	
WAIT_16MSEC 
				movlw .16	
WAIT_WMSEC 
				movwf LC+1	
WAITSET 
				movlw .250	
				movwf LC	
WAITLOOP 	
				decfsz LC,F	
				goto WAITLOOP		
				decfsz LC+1,F	
				goto WAITSET	
				return	
;=====================================================
WAIT_uS 
				movwf LC
WAIT_uS_A 
				decfsz LC, F
				goto WAIT_uS_A	
				return	
	
;=================================================================================
;Rotinas de controle do LCD
;=================================================================================
LcdInit			movlw   .40              ;Wait 30 ms
                call    LcdDelay
                
			    
                bcf     LCD_RS    ;Set LCD command mode
                bsf     LCD_DB4	;0011->48
                bsf     LCD_DB5	
				bcf     LCD_DB6
				bcf     LCD_DB7	
                call	LcdPulse_E		;sequncia de reset
                call	LcdPulse_E
                call	LcdPulse_E
				
			    bcf     LCD_DB4
				bcf     LCD_DB6
				bcf     LCD_DB7
                bsf     LCD_DB5
                call	LcdPulse_E

                movlw   28H				;Set 4 bit data bus length
                call    EC
                movlw   06H				;Entry mode set, increment, no shift
                call    EC
	 		;	movlw   0DH				;Display ON, Cursor  ON, Blink ON
	 		;	movlw   0FH				;Display ON, Cursor ALTERADO ON, Blink ON
            ;    movlw   0EH				;Display ON, Cursor ON, Blink OFF
			    movlw   0CH				;Display ON, Cursor OFF, Blink OFF
                call    EC
LcdClear		movlw   01H				;clear display
                call    EC
                movlw   .3               ;Wait 2 ms
                call    LcdDelay
                return


BIN_ASC_ED  					  ;ROTINA DE BINARIO PARA HEX 0-F COM ENVIO PARA LCD
	   			 ANDLW 0X0F                ;LIMITA 0-F
	   			 ADDLW 0XF6				  ;SOMA 0XF6
	   			 BTFSC STATUS,C            ;TESTA CARRY
	   			 ADDLW 0X07                ;C=1 ,ENTO SOMA + 7
	   			 ADDLW 0X3A                ;SOMA 0X3A
           				  ;ENVIA PARA O LCD E RETORNA PARA O PONTO DE CHAMADA


ED
LcdSendData		bsf     LCD_RS
			    GOTO    XENV
LINE1           MOVLW   0X80
                GOTO    EC
LINE2           MOVLW   0XC0
EC
LcdSendCommand	bcf     LCD_RS
XENV            

LcdSendByte		movwf   TR		;Send a byte to LCD by 4 bit data bus
				
			    bcf     LCD_DB4
				bcf     LCD_DB5
				bcf     LCD_DB6
				bcf     LCD_DB7
                btfsc   TR,4
                bsf     LCD_DB4
                btfsc   TR,5
                bsf     LCD_DB5
                btfsc   TR,6
                bsf     LCD_DB6
                btfsc   TR,7
                bsf     LCD_DB7

			

                call	LcdPulse_E
               	bcf     LCD_DB4
				bcf     LCD_DB5
				bcf     LCD_DB6
				bcf     LCD_DB7
                btfsc   TR,0
                bsf     LCD_DB4
                btfsc   TR,1
                bsf     LCD_DB5
                btfsc   TR,2
                bsf     LCD_DB6
                btfsc   TR,3
                bsf     LCD_DB7

				call	LcdPulse_E
				
                return

;LcdPulse_E	
				bsf     LCD_E     ;Enables LCD
               	NOP
				NOP
                NOP
                NOP
                bcf     LCD_E     ;Disabled LCD
			    return

LcdPulse_E		bsf     LCD_E     ;Enables LCD
               ; movlw   1               ;Wait 1ms
               ; call    LcdDelay
                movlw   .200
                call    WAIT_uS 
                bcf     LCD_E     ;Disabled LCD
               ; movlw   1               ;Wait 1ms
               ; call    LcdDelay
                return

;========================================================================
;ROTINA DE ENVIO DE FRASE INICIAL
FRASEINIT

    CLRF  PAG
	MOVLW FRASE1
	CALL  ENV_LCD
    CALL  LINE2
	MOVLW FRASE2
	CALL  ENV_LCD
    RETURN



			END








